@@ -2,7 +2,7 @@ from typing import Dict, Union
 
 import certifi
 from qase.api_client_v1 import ApiClient, ProjectsApi, Project, EnvironmentsApi, RunsApi, AttachmentsApi, \
-    AttachmentGet, RunCreate, ResultsApi, ResultcreateBulk
+    AttachmentGet, RunCreate, ResultsApi, ResultcreateBulk, AuthorsApi
 from qase.api_client_v1.configuration import Configuration
 from .. import Logger
 from .base_api_client import BaseApiClient
@@ -16,6 +16,7 @@ class ApiV1Client(BaseApiClient):
     def __init__(self, config: QaseConfig, logger: Logger):
         self.logger = logger
         self.config = config
+        self.__authors = {}
 
         try:
             self.logger.log_debug("Preparing API client")
@@ -73,7 +74,7 @@ class ApiV1Client(BaseApiClient):
             return
         try:
             api_runs.complete_run(project_code, run_id)
-            self.logger.log(f"Run {run_id} was completed successfully", "info")
+            self.logger.log(f"Test run link: {self.web}/run/{project_code}/dashboard/{run_id}", "info")
         except Exception as e:
             self.logger.log(f"Error at completing run {run_id}: {e}", "error")
             raise ReporterException(e)
@@ -87,8 +88,8 @@ class ApiV1Client(BaseApiClient):
             return response.result
 
         except Exception as e:
-            self.logger.log(f"Error at uploading attachment: {e}", "error")
-            raise ReporterException(e)
+            self.logger.log(f"Error at uploading attachment: {e}", "debug")
+            return None
 
     def create_test_run(self, project_code: str, title: str, description: str, plan_id=None,
                         environment_id=None) -> str:
@@ -106,8 +107,6 @@ class ApiV1Client(BaseApiClient):
                 run_create=RunCreate(**{k: v for k, v in kwargs.items() if v is not None})
             )
 
-            self.logger.log(f"Test run was created: {self.web}/run/{project_code}/dashboard/{result.result.id}", "info")
-
             return result.result.id
 
         except Exception as e:
@@ -138,7 +137,9 @@ class ApiV1Client(BaseApiClient):
         attached = []
         if result.attachments:
             for attachment in result.attachments:
-                attached.extend(self._upload_attachment(project_code, attachment))
+                attach_id = self._upload_attachment(project_code, attachment)
+                if attach_id:
+                    attached.append(attach_id)
 
         steps = []
         for step in result.steps:
@@ -198,6 +199,11 @@ class ApiV1Client(BaseApiClient):
         if test_ops_id:
             result_model["case_id"] = test_ops_id
 
+        if result.get_field('author'):
+            author_id = self._get_author_id(result.get_field('author'))
+            if author_id:
+                result_model["author_id"] = author_id
+
         self.logger.log_debug(f"Prepared result: {result_model}")
 
         return result_model
@@ -246,7 +252,9 @@ class ApiV1Client(BaseApiClient):
             if step.attachments:
                 uploaded_attachments = []
                 for file in step.attachments:
-                    uploaded_attachments.extend(self._upload_attachment(project_code, file))
+                    attach_id = self._upload_attachment(project_code, file)
+                    if attach_id:
+                        uploaded_attachments.append(attach_id)
                 prepared_step['attachments'] = [attach.hash for attach in uploaded_attachments]
 
             if step.steps:
@@ -257,3 +265,16 @@ class ApiV1Client(BaseApiClient):
         except Exception as e:
             self.logger.log(f"Error at preparing step: {e}", "error")
             raise ReporterException(e)
+
+    def _get_author_id(self, author: str) -> Union[str, None]:
+        if author in self.__authors:
+            return self.__authors[author]
+
+        author_api = AuthorsApi(self.client)
+        authors = author_api.get_authors(search=author)
+        if authors.result.total == 0:
+            return None
+
+        self.__authors[author] = authors.result.entities[0].author_id
+
+        return authors.result.entities[0].author_id
