@@ -1,8 +1,8 @@
-from typing import Type, Optional, Union, Dict, List
-from pathlib import PosixPath
 import time
 import uuid
-import json
+
+from typing import Type, Optional, Union, Dict, List
+from .basemodel import BaseModel
 from .step import Step
 from .suite import Suite
 from .attachment import Attachment
@@ -10,7 +10,7 @@ from .relation import Relation
 from .. import QaseUtils
 
 
-class Field:
+class Field(BaseModel):
     def __init__(self,
                  name: str,
                  value: Union[str, list]):
@@ -18,7 +18,7 @@ class Field:
         self.value = value
 
 
-class Execution(object):
+class Execution(BaseModel):
     def __init__(self,
                  status: Optional[str] = None,
                  end_time: int = 0,
@@ -47,7 +47,7 @@ class Execution(object):
         self.duration = (int)((self.end_time - self.start_time) * 1000)
 
 
-class Request(object):
+class Request(BaseModel):
     def __init__(self,
                  method: str,
                  url: str,
@@ -65,7 +65,7 @@ class Request(object):
         self.response_body = response_body
 
 
-class Result(object):
+class Result(BaseModel):
     def __init__(self, title: str, signature: str) -> None:
         self.id: str = str(uuid.uuid4())
         self.title: str = title
@@ -77,6 +77,7 @@ class Result(object):
         self.attachments: List[Attachment] = []
         self.steps: List[Type[Step]] = []
         self.params: Optional[dict] = {}
+        self.param_groups: Optional[List[List[str]]] = []
         self.author: Optional[str] = None
         self.relations: List[Type[Relation]] = []
         self.muted: bool = False
@@ -102,6 +103,9 @@ class Result(object):
     def add_param(self, key: str, value: str) -> None:
         self.params[key] = value
 
+    def add_param_groups(self, values: List[str]) -> None:
+        self.param_groups.append(values)
+
     def add_relation(self, relation: Type[Relation]) -> None:
         self.relations.append(relation)
 
@@ -137,7 +141,3 @@ class Result(object):
 
     def set_run_id(self, run_id: str) -> None:
         self.run_id = run_id
-
-    def to_json(self) -> str:
-        return json.dumps(self, default=lambda o: o.__str__() if isinstance(o, PosixPath) else o.__dict__,
-                          sort_keys=False, indent=4)
